==> s-deviation-1.0.1.tgz: package/README.md <==
[![Build Status](https://travis-ci.org/kaelzhang/s-deviation.svg?branch=master)](https://travis-ci.org/kaelzhang/s-deviation)
[![Coverage](https://codecov.io/gh/kaelzhang/s-deviation/branch/master/graph/badge.svg)](https://codecov.io/gh/kaelzhang/s-deviation)
<!-- optional appveyor tst
[![Windows Build Status](https://ci.appveyor.com/api/projects/status/github/kaelzhang/s-deviation?branch=master&svg=true)](https://ci.appveyor.com/project/kaelzhang/s-deviation)
-->
<!-- optional npm version
[![NPM version](https://badge.fury.io/js/s-deviation.svg)](http://badge.fury.io/js/s-deviation)
-->
<!-- optional npm downloads
[![npm module downloads per month](http://img.shields.io/npm/dm/s-deviation.svg)](https://www.npmjs.org/package/s-deviation)
-->
<!-- optional dependency status
[![Dependency Status](https://david-dm.org/kaelzhang/s-deviation.svg)](https://david-dm.org/kaelzhang/s-deviation)
-->

# s-deviation

Math utility to calculate [standard deviations](https://en.wikipedia.org/wiki/Standard_deviation), especially for fintech.

## Install

```sh
$ npm install s-deviation
```

## Usage

```js
import sd from 's-deviation'

sd([1, 2, 4, 8], 2)         // [0.25, 1, 4]
sd([1, 2, 3, 4, 5, 6], 4)   // [1.25, 1.25, 1.25]
```

## sd(datum, size)

- **datum** `Array.<Number>` the collection of data
- **size** `Number` the sample size of

Returns `Array.<Number>` the array of standard deviations.

## Related Modules

- [moving-averages](https://www.npmjs.com/package/moving-averages): The complete collection of utility methods for [Moving average](https://en.wikipedia.org/wiki/Moving_average)

## License

MIT

==> s-deviation-2.0.1.tgz: package/README.md <==
[![Build Status](https://travis-ci.org/kaelzhang/s-deviation.svg?branch=master)](https://travis-ci.org/kaelzhang/s-deviation)
[![Coverage](https://codecov.io/gh/kaelzhang/s-deviation/branch/master/graph/badge.svg)](https://codecov.io/gh/kaelzhang/s-deviation)
<!-- optional appveyor tst
[![Windows Build Status](https://ci.appveyor.com/api/projects/status/github/kaelzhang/s-deviation?branch=master&svg=true)](https://ci.appveyor.com/project/kaelzhang/s-deviation)
-->
<!-- optional npm version
[![NPM version](https://badge.fury.io/js/s-deviation.svg)](http://badge.fury.io/js/s-deviation)
-->
<!-- optional npm downloads
[![npm module downloads per month](http://img.shields.io/npm/dm/s-deviation.svg)](https://www.npmjs.org/package/s-deviation)
-->
<!-- optional dependency status
[![Dependency Status](https://david-dm.org/kaelzhang/s-deviation.svg)](https://david-dm.org/kaelzhang/s-deviation)
-->

# s-deviation

Math utility to calculate [standard deviations](https://en.wikipedia.org/wiki/Standard_deviation), especially for fintech.

## Install

```sh
$ npm install s-deviation
```

## Usage

```js
import sd from 's-deviation'

sd([1, 2, 4, 8], 2)         // [<1 empty item>, 0.5, 1, 2]

sd([1, 2, 3, 4, 5, 6], 4)
// [
//   <3 empty items>,
//   1.118033988749895,
//   1.118033988749895,
//   1.118033988749895
// ]
```

## sd(datum, size)

- **datum** `Array.<Number>` the collection of data
- **size** `Number` the sample size of

Returns `Array.<Number>` the array of standard deviations.

## Related Modules

- [moving-averages](https://www.npmjs.com/package/moving-averages): The complete collection of utility methods for [Moving average](https://en.wikipedia.org/wiki/Moving_average)

## License

MIT
